Index: src/crankshaft/mips/lithium-codegen-mips.cc |
diff --git a/src/crankshaft/mips/lithium-codegen-mips.cc b/src/crankshaft/mips/lithium-codegen-mips.cc |
index b826c6cd4521f7eed3c482f9d41646aa08d7120e..abbf2085c666e80c7adb882150df3d1ba34e957c 100644 |
--- a/src/crankshaft/mips/lithium-codegen-mips.cc |
+++ b/src/crankshaft/mips/lithium-codegen-mips.cc |
@@ -2796,12 +2796,12 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
__ Branch(&done, ne, result, Operand(scratch)); |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
// protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
// it needs to bail out. |
__ LoadRoot(result, Heap::kArrayProtectorRootIndex); |
__ lw(result, FieldMemOperand(result, Cell::kValueOffset)); |
DeoptimizeIf(ne, instr, DeoptimizeReason::kHole, result, |
- Operand(Smi::FromInt(Isolate::kArrayProtectorValid))); |
+ Operand(Smi::FromInt(Isolate::kProtectorValid))); |
} |
__ LoadRoot(result, Heap::kUndefinedValueRootIndex); |
__ bind(&done); |
@@ -2796,12 +2796,12 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
- // protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
+ // protector cell contains (Smi) Isolate::kProtectorValid. Otherwise |
// it needs to bail out. |
__ LoadRoot(result, Heap::kArrayProtectorRootIndex); |